@@ -1,5 +1,5 @@
 ;;  -*-  indent-tabs-mode:nil; coding: utf-8 -*-
-;;  Copyright (C) 2015,2016
+;;  Copyright (C) 2015,2016,2019
 ;;      "Mu Lei" known as "NalaGinrut" <NalaGinrut@gmail.com>
 ;;  Artanis is free software: you can redistribute it and/or modify
 ;;  it under the terms of the GNU General Public License and GNU
@@ -26,14 +26,16 @@
   #:use-module (artanis db)
   #:use-module (ice-9 match)
   #:use-module (ice-9 ftw)
-  #:use-module (ice-9 format))
+  #:use-module (ice-9 format)
+  #:use-module (ice-9 hash-table)
+  #:use-module (srfi srfi-1))
 
 (define (print-options)
   (display "\nOPTIONS:\n")
   (format #t "~2tVERSION=version~%")
   (format #t "~2t--debug~%"))
 
-(define *operators* '(up down))
+(define *operators* '(up down create))
 
 (define (print-operators)
   (display "\nOperators:\n")
@@ -66,7 +68,7 @@
 
 (define (%migrate op name opts)
   (define *mfile-re*
-    (string->irregex (format #f "^(\\d{14})_~a\\.scm$" name)))
+    (string->irregex (format #f "^~a_(\\d{14})\\.scm$" name)))
   (define (compare-mfile x y)
     (let ((mx (irregex-match-substring (irregex-search *mfile-re* x) 1))
           (my (irregex-match-substring (irregex-search *mfile-re* y) 1)))
@@ -76,7 +78,7 @@
   (define (gen-migrate-file)
     (cond
      ((assoc-ref opts 'version)
-      => (lambda (v) (format #f "~a/~a_~a.scm" path v name)))
+      => (lambda (v) (format #f "~a/~a_~a.scm" path name v)))
      (else
       (let ((fl (scandir path is-mfile)))
         (match (sort fl compare-mfile)
@@ -99,15 +101,34 @@
     ((up down create) #t)
     (else #f)))
 
+(define (show-operator-str)
+  (for-each (lambda (op) (display op) (display " ")) *operators*))
+
+(define (show-options-str)
+  (display "VERSION= --debug\n"))
+
+(define (show-scandir-str)
+  (define (filter_fun k)
+    (cond ((irregex-search "(.*)_[0-9]+[.]scm" k) => (lambda (m) (irregex-match-substring m 1)))
+          (else #f)))
+
+  (let* ((scandir_list (scandir "db/migration"))
+         (filter_list (filter-map filter_fun scandir_list))
+         (list_to_hash (alist->hash-table (map (lambda(x) (cons x x)) filter_list))))
+    (hash-for-each (lambda (k  v) (display k) (newline)) list_to_hash)))
+
 (define (do-migrate . args)
   (define (validname? x)
     (irregex-search "^-.*" x))
   (match args
+    (("migrate" "--operators") (show-operator-str))
+    (("migrate" "--options-list") (show-options-str))
+    (("migrate" "--scandir-list") (show-scandir-str))
     (("migrate" (or () (? validname?) "help" "--help" "-help" "-h")) (show-help))
     (("migrate" (? valid-operator? op) name . opts)
      (add-to-load-path (current-toplevel))
      (parameterize ((current-conf-file (gen-local-conf-file)))
-                   (init-config)) ; needs to load config
+       (init-config)) ; needs to load config
      ((@@ (artanis config) init-inner-database-item))
      (init-DB) ; needs to use DB
      (%migrate (string->symbol op) (string->symbol name) (opts-parser opts)))
